
Changelog
=========

2.0.0b1 (2016-12-15)
-----------------------------------------

* First public release by Sebastien Andrivet
* Support both python 2 and 3 (with Python-Future)
* All strings are now in unicode
* Add more ASN.1 tags (like PrintableString)
* Fix errors in the example (dump.py)
* Code reorganization

0.9 (2011-05-18)
-----------------------------------------

* Initial public release by Geert Jansen
